import { AbstractClient } from "../../../common/abstract_client";
import { ClientConfig } from "../../../common/interface";
import { ConfirmVideoTranslateJobRequest, SubmitVideoTranslateJobRequest, ConfirmVideoTranslateJobResponse, DescribeVideoTranslateJobRequest, SubmitVideoTranslateJobResponse, DescribeVideoTranslateJobResponse } from "./vtc_models";
/**
 * vtc client
 * @class
 */
export declare class Client extends AbstractClient {
    constructor(clientConfig: ClientConfig);
    /**
       * ###### 支持音色种别列表
  | 音色名称                 | 性别 | 目标语言         | 音色ID |
  | ------------------------ | ---- | ---------------- | ------ |
  | Florian Multilingual     | 男 | 德语(德国)       | 701001 |
  | Seraphina                | 女  | 德语(德国)       | 701002 |
  | Ada Multilingual         | 女 | 英语(英国)       | 701003 |
  | Ollie Multilingual       | 男  | 英语(英国)       | 701004 |
  | Ava Multilingual         | 女 | 英语(美国)       | 701005 |
  | Andrew Multilingual      | 男  | 英语(美国)       | 701006 |
  | Emma Multilingual        | 女  | 英语(美国)       | 701007 |
  | Brian Multilingual       | 男  | 英语(美国)       | 701008 |
  | Jenny Multilingual       | 女  | 英语(美国)       | 701009 |
  | Ryan Multilingual        | 男  | 英语(美国)       | 701010 |
  | Adam Multilingual        | 男  | 英语(美国)       | 701011 |
  | AlloyTurbo Multilingual  | 男  | 英语(美国)       | 701012 |
  | Amanda Multilingual      | 女  | 英语(美国)       | 701013 |
  | Brandon Multilingual     | 男  | 英语(美国)       | 701014 |
  | Christopher Multilingual | 男  | 英语(美国)       | 701015 |
  | Cora Multilingual        | 女  | 英语(美国)       | 701016 |
  | Davis Multilingual       | 男  | 英语(美国)       | 701017 |
  | Derek Multilingual       | 男  | 英语(美国)       | 701018 |
  | Dustin Multilingual      | 男  | 英语(美国)       | 701019 |
  | Evelyn Multilingual      | 女  | 英语(美国)       | 701020 |
  | Lewis Multilingual       | 男  | 英语(美国)       | 701021 |
  | Lola Multilingual        | 女  | 英语(美国)       | 701022 |
  | Nancy Multilingual       | 女  | 英语(美国)       | 701023 |
  | NovaTurbo Multilingual   | 女   | 英语(美国)       | 701024 |
  | Phoebe Multilingual      | 女  | 英语(美国)       | 701025 |
  | Samuel Multilingual      | 男  | 英语(美国)       | 701026 |
  | Serena Multilingual      | 女  | 英语(美国)       | 701027 |
  | Steffan Multilingual     | 男  | 英语(美国)       | 701028 |
  | Arabella Multilingual    | 女  | 西班牙语(西班牙) | 701029 |
  | Isidora Multilingual     | 女  | 西班牙语(西班牙) | 701030 |
  | Tristan Multilingual     | 男  | 西班牙语(西班牙) | 701031 |
  | Ximena Multilingual      | 女  | 西班牙语(西班牙) | 701032 |
  | Remy Multilingual        | 男  | 法语(法国)       | 701033 |
  | Vivienne Multilingual    | 女  | 法语(法国)       | 701034 |
  | Lucien Multilingual      | 男  | 法语(法国)       | 701035 |
  | Alessio Multilingual     | 男  | 意大利语(意大利) | 701036 |
  | Giuseppe Multilingual    | 男  | 意大利语(意大利) | 701037 |
  | Isabella Multilingual    | 女  | 意大利语(意大利) | 701038 |
  | Marcello Multilingual    | 男  | 意大利语(意大利) | 701039 |
  | Masaru Multilingual      | 男  | 日语(日本)       | 701040 |
  | Hyunsu Multilingual      | 男  | 韩语(韩国)       | 701041 |
  | Macerio Multilingual     | 男  | 葡萄牙语(巴西)   | 701042 |
  | Thalita Multilingual     | 女  | 葡萄牙语(巴西)   | 701043 |
  | 晓辰 多语言              | 女  | 中文(普通话)     | 701044 |
  | 晓晓 多语言              | 女  | 中文(普通话)     | 701045 |
  | 晓宇 多语言              | 女  | 中文(普通话)     | 701046 |
  | 云逸 多语言              | 男 | 中文(普通话)     | 701047 |
  | Yunfan Multilingual      | 男  | 中文(普通话)     | 701048 |
  | Yunxiao Multilingual     | 男  | 中文(普通话)     | 701049 |
  | 晓晓 方言                | 女  | 中文(普通话)     | 701050 |
       */
    SubmitVideoTranslateJob(req: SubmitVideoTranslateJobRequest, cb?: (error: string, rep: SubmitVideoTranslateJobResponse) => void): Promise<SubmitVideoTranslateJobResponse>;
    /**
     * 查询视频翻译任务
     */
    DescribeVideoTranslateJob(req: DescribeVideoTranslateJobRequest, cb?: (error: string, rep: DescribeVideoTranslateJobResponse) => void): Promise<DescribeVideoTranslateJobResponse>;
    /**
     * 确认视频翻译结果
     */
    ConfirmVideoTranslateJob(req: ConfirmVideoTranslateJobRequest, cb?: (error: string, rep: ConfirmVideoTranslateJobResponse) => void): Promise<ConfirmVideoTranslateJobResponse>;
}
